// Copyright (c) 2021 Terminus, Inc.
//
// This program is free software: you can use, redistribute, and/or modify
// it under the terms of the GNU Affero General Public License, version 3
// or later ("AGPL"), as published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

package apistructs

import (
	"time"

	corev1 "k8s.io/api/core/v1"
)

type ElfMetadata struct {
	ID               uint64    `json:"id"`
	Name             string    `json:"name"`
	Description      string    `json:"description"`
	Workspace        string    `json:"workspace"`
	OwnerName        string    `json:"ownerName"`
	OwnerID          uint64    `json:"ownerID"`
	OrganizationID   uint64    `json:"organizationID"`
	OrganizationName string    `json:"organizationName"`
	CreatedAt        time.Time `json:"createdAt"`
	UpdatedAt        time.Time `json:"updatedAt"`
}

type ListMetadata struct {
	Total int `json:"total"`
}

type Notebook struct {
	Metadata
	NotebookSpec
	NotebookStatus
}

type NotebookSpec struct {
	Envs             []corev1.EnvVar `json:"envs"` // 环境变量
	ClusterName      string          `json:"clusterName"`
	ProjectName      string          `json:"projectName"`
	ApplicationName  string          `json:"applicationName"`
	DBEnvs           string          `json:"-"`
	Image            string          `json:"image"`
	RequirementEnvID uint64          `json:"requirementEnvID"`
	DataSourceID     uint64          `json:"datasourceID,omitempty"`
	GenericDomain    string          `json:"genericDomain,omitempty"`
	ClusterDomain    string          `json:"clusterDomain,omitempty"`
	ElfResource      `json:"resource"`
}

type NotebookStatus struct {
	StartedAt time.Time `json:"startedAt"`
	State     string    `json:"state"`
}

type ElfResource struct {
	CPU    float64 `json:"cpu"`    // CPU 资源大小
	Memory int     `json:"memory"` // 内存资源大小
}

type NotebookResponse struct {
	Header
	Data Notebook `json:"data"`
}

type NotebookListResponse struct {
	Header
	Data NoteBookList `json:"data"`
}

type NoteBookList struct {
	ListMetadata
	NoteBookListSpec
}

type NoteBookListSpec struct {
	Items []Notebook `json:"data"`
}

type EnvironmentListResponse struct {
	Header
	Data EnvironmentList `json:"data"`
}

type EnvironmentList struct {
	ListMetadata
	EnvironmentListSpec
}

type EnvironmentListSpec struct {
	Items []Environment `json:"data"`
}

type Environment struct {
	ElfMetadata
	EnvironmentSpec
}

type EnvironmentSpec struct {
	Requires      []Require         `json:"requires"`
	DBRequires    string            `json:"-"`
	Labels        map[string]string `json:"labels"`
	DBLabels      string            `json:"-"`
	NotebookCount int               `json:"notebook_count"`
}

type EnvironmentResponse struct {
	Header
	Data Environment `json:"data"`
}

type Require struct {
	Type     string    `json:"type"`
	Packages []Package `json:"packages"`
}

type Package struct {
	Name    string `json:"name"`
	Version string `json:"version"`
}

type DependencyPackageTypeResponse struct {
	Header
	Data DependencyPackageType `json:"data"`
}

type DependencyPackageListResponse struct {
	Header
	Data DependencyPackageList `json:"data"`
}

type DependencyPackageList struct {
	ListMetadata
	DependencyPackageSpec
}

type DependencyPackageSpec struct {
	Items []DependencyPackageType `json:"data"`
}

type DependencyPackageType struct {
	Type     string                      `json:"type"`
	Packages []DependencyPackageTypeItem `json:"packages"`
}

type DependencyPackageTypeItem struct {
	Name    string   `json:"name"`
	Version []string `json:"version"`
}
